@@ -98,7 +98,7 @@ TabbedViewContainer::TabbedViewContainer(ViewManager *connectedViewManager, QWid
     connect(_contextPopupMenu, &QMenu::aboutToHide, this, [this]() {
         // Remove the read-only action when the popup closes
         for (auto &action : _contextPopupMenu->actions()) {
-            if (action->objectName() == QLatin1String("view-readonly")) {
+            if (action->objectName() == QStringLiteral("view-readonly")) {
                 _contextPopupMenu->removeAction(action);
                 break;
             }
@@ -163,7 +163,8 @@ void TabbedViewContainer::moveTabToWindow(int index, QWidget *window)
 
     QHash<TerminalDisplay*, Session*> sessionsMap = _connectedViewManager->forgetAll(splitter);
 
-    foreach(TerminalDisplay* terminal, splitter->findChildren<TerminalDisplay*>()) {
+    const QList<TerminalDisplay *> displays = splitter->findChildren<TerminalDisplay*>();
+    for (TerminalDisplay *terminal : displays) {
         manager->attachView(terminal, sessionsMap[terminal]);
     }
     auto container = manager->activeContainer();
@@ -265,9 +266,14 @@ void TabbedViewContainer::moveActiveView(MoveDirection direction)
 }
 
 void TabbedViewContainer::terminalDisplayDropped(TerminalDisplay *terminalDisplay) {
-    Session* terminalSession = terminalDisplay->sessionController()->session();
-    terminalDisplay->sessionController()->deleteLater();
-    connectedViewManager()->attachView(terminalDisplay, terminalSession);
+    if (terminalDisplay->sessionController()->parent() != connectedViewManager()) {
+        // Terminal from another window - recreate SessionController for current ViewManager
+        disconnectTerminalDisplay(terminalDisplay);
+        Session* terminalSession = terminalDisplay->sessionController()->session();
+        terminalDisplay->sessionController()->deleteLater();
+        connectedViewManager()->attachView(terminalDisplay, terminalSession);
+        connectTerminalDisplay(terminalDisplay);
+    }
 }
 
 QSize TabbedViewContainer::sizeHint() const
@@ -317,8 +323,8 @@ void TabbedViewContainer::addSplitter(ViewSplitter *viewSplitter, int index) {
     disconnect(viewSplitter, &ViewSplitter::terminalDisplayDropped, nullptr, nullptr);
     connect(viewSplitter, &ViewSplitter::terminalDisplayDropped, this, &TabbedViewContainer::terminalDisplayDropped);
 
-    auto terminalDisplays = viewSplitter->findChildren<TerminalDisplay*>();
-    foreach(TerminalDisplay* terminal, terminalDisplays) {
+    const auto terminalDisplays = viewSplitter->findChildren<TerminalDisplay*>();
+    for (TerminalDisplay *terminal : terminalDisplays) {
         connectTerminalDisplay(terminal);
     }
     if (terminalDisplays.count() > 0) {
@@ -470,7 +476,7 @@ void TabbedViewContainer::openTabContextMenu(const QPoint &point)
     //TODO: add a countChanged signal so we can remove this for.
     // Detaching in mac causes crashes.
     for(auto action : _contextPopupMenu->actions()) {
-        if (action->objectName() == QLatin1String("tab-detach")) {
+        if (action->objectName() == QStringLiteral("tab-detach")) {
             action->setEnabled(count() > 1);
         }
     }
@@ -493,7 +499,7 @@ void TabbedViewContainer::openTabContextMenu(const QPoint &point)
 
         // Disable tab rename
         for (auto &action : _contextPopupMenu->actions()) {
-            if (action->objectName() == QLatin1String("edit-rename")) {
+            if (action->objectName() == QStringLiteral("edit-rename")) {
                 action->setEnabled(!sessionController->isReadOnly());
                 break;
             }
